%global oldpkg letsencrypt

Name:           certbot
Version:        0.20.0
Release:        %mkrel 1
Summary:        A free, automated certificate authority client
Group:          Development/Python
License:        ASL 2.0
URL:            https://github.com/certbot/certbot
Source0:        https://github.com/certbot/certbot/archive/v%{version}/%{name}-%{version}.tar.gz
Source10:       certbot-renew-systemd.service
Source11:       certbot-renew-systemd.timer
Source12:       certbot-sysconfig-certbot
Source13:       README.urpmi

# In order to prevent Sphinx from contacting the network, we ship the necessary intersphinx inventory files ourselves:
# wget -O python.inv https://docs.python.org/2/objects.inv
# wget -O acme-python.inv https://acme-python.readthedocs.io/en/latest/objects.inv
# tar czf object.inv-XXX.tar.gz python.inv acme-python.inv
Source100:      object.inv-%{version}.tar.gz

BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3-future

# For the systemd macros
%{?systemd_requires}
BuildRequires:  pkgconfig(systemd)

# Required for documentation
BuildRequires: python-sphinx
BuildRequires: python-sphinx_rtd_theme
BuildRequires: python-repoze-sphinx-autointerface

#Require for testing
#BuildRequires: python3-nose-xcover
BuildRequires: python3-pep8
BuildRequires: python3-tox
BuildRequires: python3-mock
BuildRequires: python3-configargparse >= 0.10.0
BuildRequires: python3-zope-interface
BuildRequires: python3-zope-component
BuildRequires: python3-requests
BuildRequires: python3-dialog >= 3.3.0
BuildRequires: python3-psutil >= 2.1.0
BuildRequires: python3-parsedatetime
BuildRequires: python3-configobj
BuildRequires: python3-configargparse >= 0.10.0
BuildRequires: python3-acme = %{version}
BuildRequires: python3-ndg-httpsclient

Requires:   python3-configargparse >= 0.10.0
Requires:   python3-dialog >= 3.3.0
Requires:   python3-parsedatetime
Requires:   python3-mock
Requires:   python3-zope-interface
Requires:   python3-zope-component
Requires:   python3-psutil >= 2.1.0
Requires:   python3-future
Requires:   python3-configobj
Requires:   python3-acme = %{version}
Requires:   python3-ndg-httpsclient

%description
Certbot, previously the Let's Encrypt Client, is EFF's tool to obtain certs
from Let's Encrypt, and (optionally) auto-enable HTTPS on your server.
It can also act as a client for any other CA that uses the ACME protocol.

%package doc
Summary:    Documentation for Certbot
Group:      Development/Python
BuildArch:  noarch

%description doc
Certbot, previously the Let's Encrypt Client, is EFF's tool to obtain certs
from Let's Encrypt, and (optionally) auto-enable HTTPS on your server.
It can also act as a client for any other CA that uses the ACME protocol.

This package contains Certbot documentation.

%prep
%autosetup -n %{name}-%{version} -p1
cd docs
tar xzf %{SOURCE100}

%build
%py3_build

# build documentation
make \
 SPHINXOPTS="-Dintersphinx_mapping.python='python.inv' -Dintersphinx_mapping.acme='acme-python.inv'" \
 -C docs man html

%install
%py3_install
# Put the man pages in place
install -pD -t %{buildroot}%{_mandir}/man1 docs/_build/man/%{name}.1
install -pD -t %{buildroot}%{_mandir}/man7 docs/_build/man/%{name}.7
install -Dm 0644 %{SOURCE10} %{buildroot}%{_unitdir}/certbot-renew.service
install -Dm 0644 %{SOURCE11} %{buildroot}%{_unitdir}/certbot-renew.timer
install -Dm 0644 %{SOURCE12} %{buildroot}%{_sysconfdir}/sysconfig/certbot
cp %{SOURCE13} README.urpmi

%check
%{__python3} setup.py test
# Make sure the scripts use the expected python versions
grep -q %{__python3} %{buildroot}%{_bindir}/certbot

%preun
%systemd_preun certbot-renew.timer

%files
%license LICENSE.txt
%doc README.rst CHANGES.rst CONTRIBUTING.md README.urpmi
%{_bindir}/%{name}
# %doc %attr(0644,root,root) %{_mandir}/man1/%{name}*
# project uses old letsencrypt dirs for compatibility
%ghost %dir %{_sysconfdir}/%{oldpkg}
%ghost %dir %{_sharedstatedir}/%{oldpkg}
%ghost %dir %{_logdir}/%{oldpkg}
%config %{_sysconfdir}/sysconfig/certbot
%{_unitdir}/certbot-renew.service
%{_unitdir}/certbot-renew.timer
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}*.egg-info
%{_mandir}/man*/%{name}.*.xz

%files doc
%doc docs/_build/html


%changelog
* Tue Dec 12 2017 mitya <mitya> 0.20.0-1.mga6
+ Revision: 1182274
- Update to 0.20.0

* Thu Jun 08 2017 mitya <mitya> 0.14.2-2.mga6
+ Revision: 1107351
- fix BRs for systemd macro
- README.urpmi: s/Fedora/Mageia/

* Sat May 27 2017 mitya <mitya> 0.14.2-1.mga6
+ Revision: 1105149
- New version 0.14.2

* Wed May 24 2017 mitya <mitya> 0.14.1-2.mga6
+ Revision: 1104398
- remove unneeded %%post
- added %%preun

* Wed May 24 2017 mitya <mitya> 0.14.1-1.mga6
+ Revision: 1104377
- Mageify
- build mans & docs
- imported package certbot

